@@ -7,17 +7,17 @@ topidx <- function(DEM, resolution, river=NA) {
 
   ## data checking
 
-  if(!is(DEM, "matrix"))
-    stop("The DEM should be a matrix")
-  if(min(as.vector(DEM)) < -9000)
+  if(min(as.vector(DEM[!is.na(DEM)])) < -9000)
      stop("DEM contains unrealistic values (< -9000)")
   if(!is.na(river) && !is(DEM, "matrix"))
-     stop("The river should be a matrix")
+     stop("The river and DEM should both be a matrix")
   
   if(is(river, "matrix") && (min(river) < 0))
      stop("Error: the object 'river' should only contain positive values")
   else river = rep(0,nrow*ncol)
 
+  DEM[is.na(DEM)] <- -9999
+
   ## calling the function
 
   result <- .C("topidx",
@@ -35,6 +35,9 @@ topidx <- function(DEM, resolution, river=NA) {
   atb  <- matrix(result[1:(nrow*ncol)],nrow=nrow)
   area <- matrix(result[(nrow*ncol+1):(nrow*ncol*2)],nrow=nrow)
 
+  atb[atb < -9000] <- NA
+  area[area < -9000] <- NA
+
   return(list(atb = atb,area = area))
 
 }
